@@ -13,8 +13,15 @@ class UniformLengthSequenceGenerator(SequenceGenerator):
 
     def __init__(self, alphabet: Alphabet, max_seq_length: int, random_seed: int = 21, min_seq_length: int = 0):
         super().__init__(alphabet, max_seq_length, random_seed, min_seq_length)
+    
+    def generate_words(self, number_of_words: int):
+        result = np.empty(number_of_words, dtype=Sequence)
+        for index in range(number_of_words):
+            length = randint(self._min_seq_length, self._max_seq_length)
+            result[index] = self.generate_single_word(length)
+        return result
 
-    def generate_word(self, length):
+    def generate_single_word(self, length):
         if length > self._max_seq_length:
             raise AssertionError("Param length cannot exceed max_seq_length")
 
@@ -27,31 +34,4 @@ class UniformLengthSequenceGenerator(SequenceGenerator):
             value.append(symbol)
         return Sequence(value)
 
-    def generate_all_words_up_to_max_length(self):
-        ret = [Sequence([])]
-        list_symbols = list(self._alphabet.symbols)
-        list_symbols.sort()
-        for counter in range(self._max_seq_length):
-            ret_aux = ret.copy()
-            for i in range(len(ret)):
-                for symbol in list_symbols:
-                    if len(ret[i].value) >= counter:
-                        value = list(ret[i].value)
-                        value.append(symbol)
-                        extension = Sequence(value)
-                        ret_aux.append(extension)
-            ret = ret_aux
-        return ret
-
-    def generate_all_words(self):
-        list_symbols = list(self._alphabet.symbols)
-        list_symbols.sort()
-        ret = [Sequence([])]
-        while len(ret) > 0:
-            result = ret.pop(0)
-            yield result
-            for symbol in list_symbols:
-                value = list(result.value)
-                value.append(symbol)
-                extension = Sequence(value)
-                ret.append(extension)
+    
\ No newline at end of file
